use crate::{
    consts::{HOUR, MINUTE},
    Context, Error,
};

/// Move all reminders in the current server by a certain amount of time. Times get added together
#[poise::command(
    slash_command,
    identifying_name = "offset",
    default_member_permissions = "MANAGE_GUILD"
)]
pub async fn offset(
    ctx: Context<'_>,
    #[description = "Number of hours to offset by"] hours: Option<isize>,
    #[description = "Number of minutes to offset by"] minutes: Option<isize>,
    #[description = "Number of seconds to offset by"] seconds: Option<isize>,
) -> Result<(), Error> {
    ctx.defer().await?;

    let combined_time = hours.map_or(0, |h| h * HOUR as isize)
        + minutes.map_or(0, |m| m * MINUTE as isize)
        + seconds.map_or(0, |s| s);

    if combined_time == 0 {
        ctx.say("Please specify one of `hours`, `minutes` or `seconds`").await?;
    } else {
        if let Some(channels) = ctx.guild().map(|guild| {
            guild
                .channels
                .iter()
                .filter(|(_, channel)| channel.is_text_based())
                .map(|(id, _)| id.get().to_string())
                .collect::<Vec<String>>()
                .join(",")
        }) {
            sqlx::query!(
                "
                UPDATE reminders
                INNER JOIN `channels`
                    ON `channels`.id = reminders.channel_id
                SET reminders.`utc_time` = DATE_ADD(reminders.`utc_time`, INTERVAL ? SECOND)
                WHERE FIND_IN_SET(channels.`channel`, ?)
                ",
                combined_time as i64,
                channels
            )
            .execute(&ctx.data().database)
            .await
            .unwrap();
        } else {
            sqlx::query!(
                "
                UPDATE reminders
                INNER JOIN `channels`
                    ON `channels`.id = reminders.channel_id
                SET reminders.`utc_time` = reminders.`utc_time` + ?
                WHERE channels.`channel` = ?
                ",
                combined_time as i64,
                ctx.channel_id().get()
            )
            .execute(&ctx.data().database)
            .await
            .unwrap();
        }

        ctx.say(format!("All reminders offset by {} seconds", combined_time)).await?;
    }

    Ok(())
}
