use poise::{serenity_prelude::CreateEmbed, CreateReply};

use crate::{consts::THEME_COLOR, models::CtxData, Context, Error};

/// Set reminder confirmations to persist indefinitely
#[poise::command(
    slash_command,
    rename = "off",
    identifying_name = "unset_ephemeral_confirmations",
    guild_only = true
)]
pub async fn unset_ephemeral_confirmations(ctx: Context<'_>) -> Result<(), Error> {
    let mut guild_data = ctx.guild_data().await.unwrap()?;
    guild_data.ephemeral_confirmations = false;
    guild_data.commit_changes(&ctx.data().database).await;

    ctx.send(
        CreateReply::default().ephemeral(true).embed(
            CreateEmbed::new()
                .title("Confirmations public")
                .description(concat!(
                    "Reminder confirmations will be sent as regular messages, and won't be ",
                    "removed automatically."
                ))
                .color(*THEME_COLOR),
        ),
    )
    .await?;

    Ok(())
}
